@@ -86,7 +86,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -186,7 +186,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55b00
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -196,7 +196,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x55b00
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
